from clients.client import MetaClient


kwargs = {'liqui': {}, 'poloniex': {}, 'bittrex': {'api_key': None, 'api_secret': None}}
client = MetaClient(**kwargs)


if __name__ == '__main__':
    liqui_ticker = client.ticker('liqui')
    poloniex_ticker = client.ticker('poloniex')
    bittrex_ticker = client.ticker('bittrex')

    liqui_pairs = client.pairs('liqui')
    poloniex_pairs = client.pairs('poloniex')
    bittrex_pairs = client.pairs('bittrex')

    import pdb
    pdb.set_trace()


from copy import deepcopy
from mock import Mock

from fixtures.bittrex import getmarkets as bittrex_get_markets, getmarketsummaries as bittrex_get_market_summaries
from fixtures.liqui import info as liqui_info, ticker as liqui_ticker
from fixtures.poloniex import (
    returnCurrencies as poloniex_currencies, returnTicker as poloniex_ticker
)


class MockBittrexClient(Mock):

    def get_markets(self):
        return bittrex_get_markets.response

    def get_market_summaries(self):
        return deepcopy(bittrex_get_market_summaries.response)


class MockLiquiClient(Mock):

    def info(self):
        return liqui_info.response

    def ticker(self, pair):
        response = liqui_ticker.response
        pairs = pair.split('-')

        return {p: response[p] for p in pairs}


class MockPoloniexClient(Mock):

    def returnCurrencies(self):
        return poloniex_currencies.response

    def returnTicker(self):
        return poloniex_ticker.response


from setuptools import setup


setup(
    name = "crypto_mediator",
    version = "0.1.0",
    author = "Connor Wallace",
    author_email = "wallaconno@gmail.com",
    description = ('Client that allows communication between many crypto exchanges'),
    license = "MIT",
    keywords = "cryptocurrency client",
    url = "http://www.github.com/cowalla/mediator",
    packages=['crypto_mediator'],
    install_requires=[
        'astroid==1.5.3',
        'backports.functools-lru-cache==1.4',
        'backports.ssl-match-hostname==3.5.0.1',
        'bintrees==2.0.7',
        'python-bittrex==0.2.1',
        'certifi==2017.11.5',
        'chardet==3.0.4',
        'configparser==3.5.0',
        'enum34==1.1.6',
        'funcsigs==1.0.2',
        'gdax==1.0.6',
        'idna==2.6',
        'isort==4.2.15',
        'lazy-object-proxy==1.3.1',
        'liqui==1.0.1',
        'mccabe==0.6.1',
        'mock==2.0.0',
        'pbr==3.1.1',
        'python-poloniex==0.4.6',
        'py==1.5.1',
        'pylint==1.7.4',
        'pytest==3.2.5',
        'requests==2.7.0',
        'singledispatch==3.4.0.3',
        'six==1.10.0',
        'urllib3==1.22',
        'websocket-client==0.40.0',
        'wheel==0.24.0',
        'wrapt==1.10.11',
    ],
    dependency_links=[
        'git+https://github.com/ericsomdahl/python-bittrex.git',
        'git+https://github.com/s4w3d0ff/python-poloniex.git',
    ]
)


# fiat ticker names
BITCOIN = 'btc'
ETHEREUM = 'eth'
USDT = 'usdt'
LTC = 'ltc'
DASH = 'dash'
ZCASH = 'zec'

FIATS = [
    USDT,
    BITCOIN,
    ETHEREUM,
    LTC,
    DASH,
    ZCASH,
]

# character that splits currency pairs. "fiat<split>currency"
SPLIT_CHARACTER = '_'

# supported exchanges
BITTREX = 'bittrex'
GDAX = 'gdax'
LIQUI = 'liqui'
POLONIEX = 'poloniex'